@@ -44,11 +44,11 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('agent/l2_population').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/arp_responder').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/drop_flows_on_start').with_value(p[:drop_flows_on_start])
-      should contain_neutron_agent_ovs('agent/extensions').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('agent/minimize_polling').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('agent/tunnel_csum').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('ovs/datapath_type').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('ovs/vhostuser_socket_dir').with_value(['<SERVICE DEFAULT>'])
+      should contain_neutron_agent_ovs('agent/extensions').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('agent/minimize_polling').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('agent/tunnel_csum').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/datapath_type').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/vhostuser_socket_dir').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/ovsdb_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_connect_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_request_timeout').with_value('<SERVICE DEFAULT>')
@@ -57,7 +57,7 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('securitygroup/firewall_driver').\
         with_value(p[:firewall_driver])
       should contain_neutron_agent_ovs('securitygroup/enable_security_group').\
-        with_value(['<SERVICE DEFAULT>'])
+        with_value('<SERVICE DEFAULT>')
       should_not contain_neutron_agent_ovs('securitygroup/permitted_ethertypes')
       should contain_neutron_agent_ovs('ovs/tunnel_bridge').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/local_ip').with_ensure('absent')
@@ -72,7 +72,10 @@ describe 'neutron::agents::ml2::ovs' do
         with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/resource_provider_default_hypervisor').\
         with_value('<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value(['<SERVICE DEFAULT>'])
+      should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('network_log/rate_limit').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('network_log/burst_limit').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('network_log/local_output_log_base').with_value('<SERVICE DEFAULT>')
     end
 
     it 'installs neutron ovs agent package' do
